pub struct Task {
pub id: Uuid,
pub workflow_run_id: Uuid,
pub node_id: String,
pub status: TaskStatus,
pub is_master: bool,
pub master_task_id: Option<Uuid>,
pub matrix_values: Option<HashMap<String, Value>>,
pub started_at: Option<DateTime<Utc>>,
pub ended_at: Option<DateTime<Utc>>,
pub error: Option<String>,
pub logs: Vec<String>,
}Expand description
Represents a task (runtime instance of a node)
Fields
id: UuidUnique identifier for the task
workflow_run_id: UuidID of the workflow run this task belongs to
node_id: StringID of the node this task is an instance of
status: TaskStatusCurrent status of the task
is_master: boolWhether or not this task is a master task for other matrix tasks.
master_task_id: Option<Uuid>For matrix tasks, the master task ID
matrix_values: Option<HashMap<String, Value>>For matrix tasks, the matrix values
started_at: Option<DateTime<Utc>>Start time of the task
ended_at: Option<DateTime<Utc>>End time of the task (if completed or failed)
error: Option<String>Error message (if failed)
logs: Vec<String>Logs from the task
Implementations